%         This script calls and runs the function swirl_func3_deliq  
%         which will do all calculations for the separation          
%         process in the Deliquidizer. This script will then         
%         generate the results and graphs from the process.          
                                                                  
%         Author: Torstein Bishop, Department of Chemical            
%        Engineering, NTNU. Fall 2015.                              


clc
clear all
%% Performing the calculations of the separator
Vg_in = 0.8; %Gas fraction into separator
qin = [85:1:330]; %Inlet flow-rate into separator [m3/h]
FS = [0.2:0.05:0.95]; %Flow split between top and bottom outlet stream.

Vg_HPO=zeros(length(qin),length(FS));    % HPO gas cut
Vg_LPO=zeros(length(qin),length(FS));    % LPO gas cut
GR=zeros(length(qin),length(FS));        % Gas Recovery
Esplit=zeros(length(qin),length(FS));    % Split efficiency

for i = 1:length(qin)
    for j = 1:length(FS)
   
    [Vg_LPO(i,j),Vg_HPO(i,j),GR(i,j),Esplit(i,j),qen(i,j)]...
            = swirl_func3_deliq(Vg_in,qin(i)/3600,FS(j));
    end
end

%% Generating plots
% GVF, LVF, GR and Esplit as a function of qin, FS = 0.8 (index = 13)
figure(1)
subplot(2,2,1)
plot(qin,Vg_LPO(:,13),'k')
axis([85 330 0.5 1])
xlabel('q_{in} [m^{3}/h]','FontSize',12)
ylabel('GVF_{LPO}','FontSize',12)
title('Gas Volume Fraction at LPO')


subplot(2,2,2)
plot(qin,1-Vg_HPO(:,13),'k')
axis([85 330 0 1])
xlabel('q_{in} [m^{3}/h]','FontSize',12)
ylabel('LVF_{HPO}','FontSize',12)
title('Liquid Volume Fraction at HPO')

subplot(2,2,3)
plot(qin,GR(:,13),'k')
xlabel('q_{in} [m^{3}/h]','FontSize',12)
ylabel('GR','FontSize',12)
title('Gas Recovery')
axis([85 330 0.5 1])

subplot(2,2,4)
plot(qin,Esplit(:,13),'k')
xlabel('q_{in} [m^{3}/h]','FontSize',12)
ylabel('\eta_{Split}','FontSize',15)
title('Split efficiency')
axis([85 330 0.5 1])

% GVF,LVF, GR and Esplit as a function of FS, qin = 140 (index = 56)
figure(2)
subplot(2,2,1)
plot(FS,Vg_LPO(56,:),'k')
xlabel('FS [-]','FontSize',12)
ylabel('GVF_{LPO}','FontSize',12)
title('Gas Volume Fraction at LPO')

subplot(2,2,2)
plot(FS,1-Vg_HPO(56,:),'k')
%axis([85 350 0 1])
xlabel('FS [-]','FontSize',12)
ylabel('LVF_{HPO}','FontSize',12)
title('Liquid Volume Fraction at HPO')

subplot(2,2,3)
plot(FS,GR(56,:),'k')
xlabel('FS [-]','FontSize',12)
ylabel('GR','FontSize',12)
title('Gas Recovery')
%axis([85 350 0.5 1])

subplot(2,2,4)
plot(FS,Esplit(56,:),'k')
xlabel('FS [-]','FontSize',12)
ylabel('\eta_{Split}','FontSize',15)
title('Split efficiency')
%axis([85 350 0.5 1])


%% Analysis and Separator profiles
Lsw = 1.5; %Separator length
Ro = 0.075; % Separator radius
Ri = sqrt(4/5)*Ro; % Gas-extraction radius

rad = [0.001:0.001:0.075]; % Vector of radius of separator
l = [0:0.1:1.5]; % Vector of length through separator
FS2 = 0.8; %Flow split
for i = 1:length(qin)
    
    % Tangential velocity equations
    Rc=0.25*Ro; %Critical radius
    va=(qin(i)/3600)/(pi*Ro^2); %Axial velocity
  
  
    k=0.1; %swirl number 
    vt0(i)=k*va; % Tangential velocity immediately after the swirl element
    vt_quad(i) = (vt0(i))^2;
    
    
    qi=FS2*(qin(i)/3600);      %Light phase out flow
    qo=(qin(i)/3600)-qi;      %Heavy phase out flow

    ta(i)=(pi*Ri^2*Lsw)/qi; %Residence time

% 
         for j = 1:length(rad)
             for k = 1:length(l)
                % Finding the tangential velocity at a given place in the
                % separator
                f2=(vt0(i)*exp(-0.04*l(k)/(2*Ro)))^2/rad(j);
                f1=(vt0(i)*exp(-0.04*l(k)/(2*Ro))/Rc)^2*rad(j);
                f=f2-f1;
                beta=1; %Smoothing parameter
                ac(i,j,k)=f2-0.5*((f^2+beta^2)^.5+f);
             end
         end
    
    % Droplet radius equations
    rd(i) = (-0.6*(qin(i))*1E-6+0.0002)/2;
    
    % Re-entrainment equations
    
    u_LPO(i)=qi/(pi*Ri^2);
    u_HPO(i)=qo/(pi*(Ro^2-Ri^2));
    du=u_LPO(i)-u_HPO(i);
    kreen=2*10^-4; %Re-entrainment proportionality constant
    qen1(i)=kreen*du;
    
end

figure(5)
plot(qin,vt0,qin,vt_quad)
xlabel('q_{in}')
ylabel('Tangential velocity after swirl-element and quadratic')

rd1 = rd*1E6;

figure(6)
plot(qin,rd1,'k')
xlabel('q_{in} [m^3/h]','FontSize',12)
ylabel('Droplet radius [\mum]','FontSize',12)
axis([85 330 0 80])

figure(7)
plot(qin,qen1)
xlabel('q_{in}')
ylabel('Re-entrainment rate')

figure(8)
plot(qin,u_LPO,qin, u_HPO,qin,vt0)
xlabel('q_{in}')
ylabel('Axial velocity')
legend('LPO velocity','HPO velocity','v_{\theta}^{max}')


% Centripetal acceleration at qin=85
ac85 = squeeze(ac(1,:,:));

figure(9)
%surf(l,rad,ac85)
surf(l,rad,ac85)
ylabel('Separator radius [m]')
xlabel('Separator length [m]')
zlabel('a_{c} [m/s^{2}]')
title('q_{in} = 85 m^{3}/h')

% Centripetal acceleration at qin=140
ac140 = squeeze(ac(56,:,:));

% 
figure(10)
surf(l,rad,ac140)
ylabel('Separator radius [m]')
xlabel('Separator length [m]')
zlabel('a_{c} [m/s^{2}]')
 title('q_{in} = 140 m^{3}/h')
% 
% % Centripetal acceleration at qin=217
ac217 = squeeze(ac(133,:,:));

 
figure(11)
surf(l,rad,ac217)
ylabel('Separator radius [m]')
xlabel('Separator length [m]')
zlabel('a_{c} [m/s^{2}]')
title('q_{in} = 217 m^{3}/h')
% 
% 
% %Centripetal acceleration at q = 300
ac300 = squeeze(ac(216,:,:));
 
figure(12)
surf(l,rad,ac300)
ylabel('Separator radius [m]')
xlabel('Separator length [m]')
zlabel('a_{c} [m/s^{2}]')
title('q_{in} = 300 m^{3}/h')
 
figure(13)
plot(qin,ta,'k')
xlabel('q_{in} [m^3/h]','FontSize',12)
ylabel('Residence time, \tau, [s]','FontSize',12)
axis([85 330 0.2 1.2])


